#
# spec file for package xfdesktop
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with git
Name:           xfdesktop
Version:        4.20.0
Release:        2.1
Summary:        Desktop Manager for the Xfce Desktop Environment
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/xfce/xfdesktop/start
Source0:        https://archive.xfce.org/src/xfce/xfdesktop/4.20/%{name}-%{version}.tar.bz2
# PATCH-FEATURE-OPENSUSE xfdesktop-backgrounds-path.patch bnc#800970 gber@opensuse.org -- Deliver background images under DATADIR/wallpapers which is already used by openSUSE and fix the default path for background images in the settings dialog
Patch0:         xfdesktop-backgrounds-path.patch
# PATCH-FIX-OPENSUSE 0001-relax-x11-version.patch -- Allow build for Leap with its ancient but sufficient X11 packages.
Patch1:         0001-relax-x11-version.patch
# PATCH-FIX-OPENSUSE 0002-relax-libyaml-version.patch -- Allow build for Leap with its ancient but sufficient libyaml packages.
Patch2:         0002-relax-libyaml-version.patch
%if 0%{?suse_version} && 0%{?suse_version} < 1550
# Default gcc7 is too old for new C20 features
BuildRequires:  gcc13
%endif
BuildRequires:  fdupes
BuildRequires:  gettext >= 0.19.8
BuildRequires:  update-desktop-files
BuildRequires:  xfce4-dev-tools
BuildRequires:  pkgconfig(cairo) >= 1.16
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(exo-2) >= 0.11.0
BuildRequires:  pkgconfig(garcon-1) >= 0.6.0
BuildRequires:  pkgconfig(gdk-wayland-3.0) >= 3.24.10
BuildRequires:  pkgconfig(gio-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gthread-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(gtk-layer-shell-0) >= 0.7.0
BuildRequires:  pkgconfig(libnotify) >= 0.4.0
BuildRequires:  pkgconfig(libwnck-3.0) >= 3.14
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.18.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.13.0
BuildRequires:  pkgconfig(libxfce4windowing-0) >= 4.19.8
BuildRequires:  pkgconfig(libxfconf-0) >= 4.19.3
BuildRequires:  pkgconfig(thunarx-3) >= 4.17.10
BuildRequires:  pkgconfig(x11) >= 1.6.5
BuildRequires:  pkgconfig(yaml-0.1) >= 0.1.7
Provides:       xfce4-desktop = %{version}
Obsoletes:      xfce4-desktop < %{version}
Requires:       %{name}-branding = %{version}
# menu data
Requires:       libgarcon-data
# uses exo-desktop-item-edit
Requires:       exo-tools
Recommends:     %{name}-lang = %{version}

%description
Xfdesktop is a desktop manager for the Xfce Desktop Environment which can set
the background image, provides a right-click menu to launch applications and
can optionally show files (including application launchers) or iconified
windows, includes gradient support for background color, saturation support for
background images, as well as real multiscreen and xinerama support.

%package branding-upstream
Summary:        Upstream Branding of xfce4-settings
# BRAND: default.jpg: Control the default backdrop image.
Group:          System/GUI/XFCE
Conflicts:      otherproviders(%{name}-branding)
Provides:       %{name}-branding = %{version}
Provides:       xfce4-desktop-branding-upstream = %{version}
Obsoletes:      xfce4-desktop-branding-upstream < %{version}
Supplements:    packageand(%{name}:branding-upstream)
BuildArch:      noarch

%description branding-upstream
This package provides the upstream look and feel for the Xfce Desktop Manager.

%lang_package

%prep
%autosetup -p1

%build
%if 0%{?suse_version} && 0%{?suse_version} < 1550
export CC=gcc-13
%endif
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-maintainer-mode
    --with-default-backdrop-filename=%{_datadir}/wallpapers/xfce/default.wallpaper
%else
xdt-autogen
%configure \
    --with-default-backdrop-filename=%{_datadir}/wallpapers/xfce/default.wallpaper
%endif
%make_build

%install
%make_install

# default upstream backdrop image
ln -s %{_datadir}/wallpapers/xfce/xfce-blue.jpg \
    %{buildroot}%{_datadir}/wallpapers/xfce/default.wallpaper

%suse_update_desktop_file xfce-backdrop-settings

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc README.md AUTHORS NEWS
%license COPYING
%{_bindir}/xfdesktop
%{_bindir}/xfdesktop-settings
%{_datadir}/applications/xfce-backdrop-settings.desktop
%{_datadir}/pixmaps/*.png
%{_datadir}/icons/hicolor/*/*/*.png
%{_datadir}/icons/hicolor/*/*/*.svg
%{_mandir}/man1/xfdesktop.1.gz
%{_datadir}/pixmaps/xfdesktop
%dir %{_datadir}/wallpapers
%dir %{_datadir}/wallpapers/xfce
%{_datadir}/wallpapers/xfce/*.jpg
%{_datadir}/wallpapers/xfce/*.svg

%files lang -f %{name}.lang

%files branding-upstream
%{_datadir}/wallpapers/xfce/default.wallpaper

%changelog
* Wed Jan  1 2025 Manfred Hollstein <manfred.h@gmx.net>
- Use --with-default-backdrop-filename to specify the default
  backdrop image on openSUSE; fix typo in its argument.
* Sun Dec 15 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.20.0:
  * Fix incorrect format passed to gtk_selection_data_set()
  * Update POTFILES.in
  * Updated backgrounds/README.md for Xfce-4.20
  * Add license and author metadata to new Xfce-4.20 wallpapers
  * New wallpaper for Xfce-4.20
  * New default wallpaper for Xfce-4.20
  * xfdesktop-file-utils: Unset custom window cursor
  * Translation Updates
- Refresh 0001-relax-x11-version.patch and
  0002-relax-libyaml-version.patch
* Sun Dec  1 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.7 [development branch]
  * Replace color1 and color2 with rgba1 and rgba2 in README.xfconf
  * Add more instructions to GitLab issue template
  * Add existing workspaces after monitor gets added
  * I18n: Update po/LINGUAS list
  * Stop timer when finalizing backdrop cycler
  * Fix GFileInputStream leaks in file_input_stream_ready_cb
  * Assign correct initial image to backdrop cycler
  * Fix build with just file icons disable or just desktop icons disabled
  * Translation Updates
- Refresh 0001-relax-x11-version.patch and
  0002-relax-libyaml-version.patch
* Sat Nov  2 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.6 [development branch]
  * Add a few environment settings to gitlab issue template
  * Fix leak when dragging icons
  * bump copyright
  * Bump libxfce4windowing requirement to 4.19.8
  * Ignore the result of g_volume_can_mount()
  * Add GMount instances to the hash table always
  * Bump xfconf requirement and stop using
    xfconf_g_property_bind_gdkrgba()
  * Fix GArray leak in xfdesktop_keyboard_shortcut_settings_init
  * Add issue template
  * Fix string leak in cb_image_selection_changed
  * Fix string leak in update_icon_view_model
  * Fix GFile leak in backdrop cycler
  * Reset backdrop cycler timer if user manually changes the image
  * Add all background dirs to the settings chooser button shortcuts
  * Fix GFileInfo leak in xfdesktop_special_file_icon_new
  * Clean up PARAM_FLAGS in icon view
  * Clean up cell renderer init & management in the icon view
  * Fix leaks in xfdesktop_icon_view_constructed
  * Remove unused version.sh script
  * Translation Updates
- Add 0001-relax-x11-version.patch to allow build for Leap with its
  ancient but sufficient X11 packages.
- Add 0002-relax-libyaml-version.patch to allow build for Leap with its
  ancient but sufficient libyaml packages.
- BuildRequire: gcc13 on Leap
* Wed Oct 16 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.5 [development branch]
  * Rework how icon pointer "hit detection" works
  * Fix g-critical warning when starting a drag *just* outside the icon
    area
  * Tell GtkTooltip the region the tooltip is for
  * Add option to sort folders before files (Issue #332)
  * Fix leaks in xfdesktop_file_utils_next_new_file_name
  * Fix string leak in xfdesktop_icon_view_show_tooltip
  * Fix GIcon leak in xfdesktop_icon_view_manager_sort_icons
  * Reword a couple settings option names, fix some accelerators
  * Only clear drag/context menu timeout if a drag actually starts
  * settings: define infobar_label in glade file, not in code
  * settings: avoid flashing an empty info bar on startup
  * settings: enumerate image folder fully asynchronously
  * settings: change icon view selection if background changes externally
  * Merge branch xfdesktop:master into master
  * Refactor settings dialog code
  * Fix memory corruption in icon view's tooltip size changed handler
  * Redesign the 'Desktop Icons' tab in the settings dialog
  * Decouple refreshing the desktop with cycling the backdrop
  * Sort all desktops vs. just one based on where the event came from
  * Improve how the "active" desktop is tracked
  * Add a root context menu for the window icon manager
  * Fix invalid read when changing foreground color
  * Fix string leak in save_icons
  * Make icon sorting confirmation dialog optional (Issue #266)
  * Added missing Keywords entry to .desktop file
  * Don't remove icon position from current config
  * Use g_ascii_dtostr() instead of custom decimal-printing hack
  * Update icon view's item_under_pointer on button presses as well
  * Simplify XfdesktopIconView->item_under_pointer tracking code
  * Fix icon DnD between two monitors with the same priority
  * Modernize GObject usage in XfdesktopThumbnailer
  * Modernize GObject usage in XfceDesktop
  * Remove spurious newly added #include
  * Modernize GObject in XfdesktopIconView
  * Avoid printing GTK CSS with commas as the decimal separator
  * Add ability to set custom icon label text and background colors
  * Fix xfdesktop_icon_view_invalidate_item_text()
  * Fix memleak when XfdesktopCellRendererIconLabel freed
  * Better way to fix monitor removal
  * Don't reschedule icon positions save
  * Reduce icon positions save delay to 1 second
  * Fix desktops not being removed when a monitor is disconnected
  * Fix icon view ascending vs. descending sort order
  * I give up.  Icon label backgrounds are transparent again.
  * Add windowlist options for showing all workspaces & urgent windows
  * Use #defines for windowlist prop names everywhere
  * Use windowlist menu widget from libxfce4windowingui
  * Add XF_DEBUG when icon added to file model
  * Actually rearrange the settings panels
  * Use new xfw_window_activate() signature in libwindowing 4.19.6
  * Use a swapped signal connection so session_die() gets the right arg
  * Exclude some menu entries from multi selection
  * Simplify menu code
  * Move Keyboard Shortcuts settings tab to the end
  * Fix timer getting stopped on file deletion
  * Don't repeat backdrop images when cycling randomly
  * Change the backdrop cycler to use GFile throughout
  * Fix backdrop cycler property names
  * Fix GFileInfo leak in check_create_desktop_folder
  * Remove unused last_filename field to fix leak
  * Fix string leak in save_icons
  * Fix string leak in set_accountsservice_user_bg
  * Allow space chars to work for keyboard navigation
  * Remove manual activation of icon view binding set
  * Add configurable keybinding for toggle-cursor for the icon view
  * Remove unneeded debugging statements
  * Don't use meson.project_source_root()
  * Don't use relative source path in tests/meson.build
  * build: Adjust requirements for Xfce 4.20
  * Fix new-folder icon missing on some icon themes
  * Translation Updates
- Remve ddccb1f4eb753eee69c80608e38b5ff110f78409.patch which is
  included upstream now.
* Mon Oct  7 2024 Manfred Hollstein <manfred.h@gmx.net>
- Add ddccb1f4eb753eee69c80608e38b5ff110f78409.patch to comply with
  the libxfce4windowing-4.19.6 ABI/API breaking changes.
- Update to version 4.19.4 [development branch]
  * Don't use XfceSMClient on Wayland
  * Fix crash when double-clicking file icons
  * Grey out children of removable devices option when disabled
  * Add more compiler flags to the meson build
  * Add editable keyboard shortcuts for the desktop and icon view
  * settings: Fix string leak
  * Remove xfdesktop_icon_view_model_set_monitor()
  * Simplify icon add/remove code in file icon model
  * Fix removable devices not getting removed properly on reload
  * Cancel desktop folder enumeration on reload
  * Add option to show fixed drives and devices
  * Only draw icon focus rectangle for keyboard-driven selections
  * Mirror thunar's behavior for the new file/folder dialogs
  * Ensure drag highlight is cleared when file drag ends
  * Make XdndDirectSave file write asynchronous
  * Remove TODO
  * Update some source file copyright years
  * Build on glib 2.72
  * Fix _NETSCAPE_URL drops
  * Remove unused variable
  * Fix string leak in xfdesktop_application_theme_changed
  * Don't ship generated sources in the dist tarball
  * Include meson build files in autotools dist tarball
  * Add gresource XML files to EXTRA_DIST
  * Back up invalid icon position config files instead of overwriting
  * Simplify deletion/trashing code
  * Use more reliable way to get a toplevel parent for dialogs
  * Fix icon positioning for create launcher/link
  * Check if icon position changed on row-changed and replace if needed
  * Fix new folders and template creation appearing in wrong position
  * Fix memleak when checking if template menu has items
  * Treat icon views independently when handling file icon selection
  * Fix icon drops from external sources showing up on the wrong monitor
  * Rewrite the monitor mirror detection and handling
  * Move all removable volume filtering into the filter model
  * Display icons for mounts that don't have an associated volume
  * Modernize GObject use in XfdesktopIcon & subclasses
  * Fix keyboard focus for icon view when clicked
  * Make file icon manager reload icons when asked
  * Add debugging for desktop reposition on monitor geom change
  * Fix race condition when monitor geometry changes
  * Fix typo in icon view placement code
  * Simplify how the "backdrop workspace" is tracked in XfceDesktop
  * Fix same-filename backdrop toggle causing issues
  * Implement new DnD
  * Simplify icon view widget coords -> slot coords code
  * Handle mirrored monitors
  * Fix copy/paste error
  * Fix context menu popups
  * Let XfdesktopIconView have its own window
  * Cache icon identifier in XfdesktopIcon
  * Fix X11 icon view positioning
  * Attempt to migrate old position config to new
  * Refactor the grid sizing code a little
  * Implement new multi-monitor support for the file icon manager
  * Ensure xfdesktop_icon_get_identifier() never returns NULL
  * Add new YAML icon position saving code
  * Simplify and clean up a bunch of code in the file icon manager
  * Reduce boilerplate when building file icon context menu
  * Move file icon settings filtering to a GtkTreeModelFilter subclass
  * Better way to deal with monitors coming and going
  * Migrate old .png background filenames to .svg
  * Clean up monitor workarea tracking in XfdesktopIconViewHolder
  * Track desktop monitor changes in XfdesktopIconViewHolder
  * Signal model row changed when XfwWindow:monitors changes
  * Redo how monitor changes are handled in the backdrop manager
  * Create/destroy/update XfceDesktop instances on monitors-changed
  * Prevent xfdesktop from quitting if there are no monitors
  * Fix dangling signal connections in XfceDesktop
  * XfceDesktop: clean up x11 compat properties management
  * Use GList for XfdesktopApplication->desktops
  * Allow dragging window icons between monitors
  * Clean up more gcc-analyzer warnings
  * Modernize gobject use in XfdesktopFileIconManager
  * Get rid of unused marshal functions
  * Move file icon loading/management to the model
  * Rewrite window icon manager to display on all monitors
  * Update everything to use XfwMonitor
  * Use a separate XfceDesktop widget/window per monitor
  * Fix --reload option
  * Fix memleak freeing result of xfdesktop_icon_view_get_selected_items()
  * Fix some memory leaks with gdk_atom_name()
  * Updates to meson build
  * Fix use-after-free in the regular file icon tooltip code
  * Revert text shadow change in fallback theme
  * Fix PangoLayout memory leak in XfdesktopCellRendererIconLabel
  * Improve fallback theme
  * Resolve conflicting mnemonics
  * fix HAVE_THUNARX
  * Fix wrong filename in EXTRA_DIST in backgrounds/
  * Add README for backgrounds, with provenance and licensing info
  * SVG wallpapers with licenses
  * Translation Updates
- Update to version 4.19.3 [development branch]
  * Add false positives file for scan-build
  * Silence some scan-build warnings
  * Fix gcc-analyzer warnings
  * meson: use x11 & wayland option names, rather than windowing-systems
  * Fix broken icon sorting direction
  * Fix monitoring of folder icon files in subdirs
  * Rework the icon view grid sizing and placement code a bit
  * Fix long-standing memory leak in XfdesktopIconView
  * Make desktop folder loading cancellable
  * Fix default-backdrop-filename option for meson build
  * build: clang: Fix -Wcast-align
  * build: Fix -Werror=format=
  * Invalidate icon surface cache on icon theme change
  * Revert "Add CI builds for --disable-x11 and --disable-wayland"
  * Add missing menu separators
  * Fix invalid param flags
  * Fix some default settings not being applied on startup
  * Only redraw icon text when focus changes
  * Compute icon invalidation rect more generously
  * Only resize grid on size_allocate if the allocation actually changed
  * Resize icon grid if style changes affect slot/cell size
  * Don't invalidate the icon view pixbuf cache on style update
  * Be more precise in what gets redrawn
  * Clean up xfdesktop_volume_icon_menu_eject()
  * Fix safe removal for unmounted volumes
  * Icon view should not accept focus in order to reduce redraws
  * Fix xfdesktop no longer being saved as part of the session
  * Remove icon view manager's update_workarea vfunc
  * Move GdkScreen::size-changed handler to XfdesktopIconViewManager
  * Resize icon grid on size change even if we don't have our own window
  * Handle monitors-changed in the icon view manager
  * Resize and reposition icon view when workarea changes
  * Remove XfdesktopIconView's show-icons-on-primary property
  * Use 65%% for the window icon opacity value
  * Clamp the icon opacity value where it actually needs to be used
  * Restore behavior where unmounted volume icons are drawn 50%% opaque
  * Fix icon view not getting motion events
  * Fix build error when full debug enabled
  * Add meson build
  * Fix wrong property name for icons-on-primary
  * Reduce copy-paste duplication in XfdesktopRegularFileIcon
  * Simplify a bunch of code and reduce duplication in
    XfdesktopApplication
  * Clear out XfdesktopApplication singleton pointer on finalize
  * Reduce duplicated code in app action init
  * Fix crash on startup with WM check, refactor
  * Start isolating X11 code as much as possible
  * Ensure workspaces are fully initialized on construction
  * Don't allow bg_surface to be NULL
  * Don't spuriously print that we're already running when starting up
  * Refactor the GApplication stuff
  * Fix warnings on --quit when xfdesktop isn't running
  * Avoid a critical warning depending on init order
  * Translation Updates
* Tue Apr  2 2024 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.19.2 (development branch)
- Removed obsolete xfdesktop-default-background-image.patch as a config
  option available at build time
* Sat Jan 21 2023 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.18.1:
  * Load removable volume information asynchronously
  * Fix apps menu not popping up when menu icons disabled
  * Translation Updates
* Wed Dec 21 2022 Manfred Hollstein <manfred.h@gmx.net>
- Rebase xfdesktop-default-background-image.patch for Xfce 4.18
- Add *.svg wallpapers to the file list
* Mon Dec 19 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.18.0
  * Bump requirements for Xfce 4.18
  * Add wallpapers of Xfce 4.18 wallpaper contest
  * Delete" menu entry in the context menu can now be hidden.
  * On pressing 'rearrange desktop icons', the user is asked for confirmation
  * Translation Updates
  * For the complete list of changes from the development branch 4.17 please
    see the packaged NEWS file
- Removed unused _service file
* Sun Aug 21 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.16.1
  - Resolve deadlock on background change (gxo#xfce/xfdesktop#188)
  - Allocate memory after error processing
  - Remove unused function call (gxo#xfce/xfdesktop#157)
  - autoconf: Remove AC_HEADER_STDC
  - Do not delete property not set
  - Set a pixmap XID, not the XID of the root window (gxo#xfce/xfdesktop#62)
  - Fix next background (gxo#xfce/xfdesktop!16)
  - build: Fix intltool lock file problem during make distcheck
  - Increase opacity of xfce-verticals bg (gxo#xfce/xfdesktop#125)
  - Fix Applications Menu memory leak (gxo#xfce/xfdesktop#102)
  - Fix gettext extraction from settings/xfce-backdrop-settings.desktop.in.in
  - Translation Updates
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.16.0
  - Set new wallpaper as default
  - Add wallpaper for 4.16
  - settings: Drop subtitle
  - Drop autogenerated xfce-backdrop-settings.desktop.in from git
  - Remove GLIB_CHECK_VERSION IFDEFs which are obsolete after glib bump
  - bump glib (and gio, gthread, etc) minimum to 2.50.0
  - Remove GSourceFunc casts
  - Avoid warning, pointer target in assignment differ in signedness
  - Translation Updates
* Mon Nov  2 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.1
  * Add keywords to .desktop files in xfdesktop
  * Add 24px and 32px icons
  * Remove extra separator from context menu
  * Move 'Open in New Window' of root window context menu
    (gxo#xfce/xfdesktop#59)
  * Remove "Properties..." entry from desktop context menu
    (gxo#xfce/xfdesktop#59)
  * Translation Updates
* Fri Aug 28 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.0
  * Pull in new fallback icon from Adwaita
  * Add new app icon and switch to rDNS icon name
  * Avoid redundant calls to backdrop_changed_cb (bxo#16773)
  * Move from exo-csource to xdt-csource (bxo#16717)
  * Increase minimum desktop icon size to 16 (bxo#16667)
  * Correct spelling of file system (bxo#16543)
  * Increase desktop icon increments to 2 (bxo#16668)
  * Unselect all items after single click activation
  * Fix memory leak when reconnecting DP monitor (bxo#16314)
  * Fix regression caused by (bxo#16342)
  * Fix transparent background color (bxo#16380)
  * Add Shift+Ctrl+N keybinding for Create Folder (bxo#15660)
  * Ignore modifier key events in type-ahead find (bxo#11149)
  * Added type-ahead find for Desktop icons (bxo#11149)
  * Do not insert hyphens at intra-word line breaks (bxo#16339)
  * Replace deprecated G_FILE_MONITOR_EVENT_MOVED (bxo#16342)
  * Translation Updates
- Removed xfce-backdrop.patch
* Thu Apr  9 2020 Jonas Kvinge <jonas@jkvinge.net>
- Add xfce-backdrop.patch for bxo#16314 - Possible memory leak
  in xfdesktop when connecting and disconnecting DP monitor.
* Mon Jan 13 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.14.2
  * Update thumbnail when file changes (bxo#14919)
  * Add DnD support for application/octet-stream (bxo#14919)
  * windowlist: Fix ellipsizing (bxo#15851)
  * Add padding to custom actions without icon (bxo#14628)
  * Fix yet another rubber band DnD issue (bxo#16046)
  * Reintroduce workaround for bxo#11283
  * Show file names in tooltips (bxo#15899)
  * fallback style: Highlight selected icons (bxo#15866)
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Mon Aug 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.14.1
  * Ensure the new default wallpaper gets installed
* Mon Aug 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.14.0
  * Add 4.14 wallpaper
  * Do not query file information again (bxo#15460)
  * Replace GtkStock buttons
  * Translation updates
- Fixed up spec file
- Rebased xfdesktop-default-background-image.patch
- Rebased xfdesktop-backgrounds-path.patch
* Sun Jul 28 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.13.6
  * Update copyright year
  * Use https where possible
  * Add padding to Window Actions menu entry (bxo#14628)
  * Display correct icon size of minimized apps (bxo#8951)
  * Reorder checkboxes in Settings UI
  * Translation updates
* Sun Jun 30 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.13.5
  * Highlight drag target when hovering it (bxo#12695)
  * Fix drag data being received multiple times (bxo#14471)
  * Allow to load non-theme icons (bxo#15294)
  * Add Next Background option (bxo#12261)
  * Do not cycle backdrop twice
  * Ensure that CSD is not applied to desktop window (bxo#15241)
  * Use async dbus proxy initialization (bxo#15418)
  * Open all selected icons on key press (bxo#15420)
  * Improve fallback CSS
  * Fix warning about ignoring return value (bxo#15410)
  * Update README.xfconf (bxo#15457)
  * Translation Updates
- Removed unneeded BuildRoot
- Changes from version 4.13.4
  * Re-introduce ability to move icons to other displays
    (bxo#15198)
  * Make 'Move to Trash' icon the same as Thunar (bxo#15234)
  * Match Thunar Drag and Drop behavior (bxo#14919)
  * Stop ongoing drag/selection if middle/right mouse button is
    pressed (bxo#14180)
  * Fix Desktop icons order resets, by adding link to last used
    configuration as fallback (bxo#11266)
  * Fix xfdesktop crashes after multiples --reload (bxo#15060)
  * Fix scaling of images with orientation metadata (bxo#14644)
  * Fix stretching/zooming of images with orientation metadata
    (bxo#15292)
  * Fix has_mime_type implementation (bxo#15295)
  * Use clipboard target "text/uri-list" when copying/cutting
    (bxo#13379)
  * Set desktop environment for garcon app menu (bxo#14599)
  * Remove faulty line in glade file (bxo#15293)
  * Fix g_type_class_add_private is deprecated
  * Avoid invalid memory access (bxo#15299)
  * Avoid timer leak when docking-undocking monitors (bxo#13887)
  * Use clipboard target "text/uri-list" when copying/cutting
    (bxo#13379)
  * Set desktop environment for garcon app menu (bxo#14599)
  * Properly center workspace header in windowlist (bxo#15405)
  * Fix memory leak when monitors change (bxo#14844)
  * Replace/remove deprecated functions
  * Translation Updates
- Changes from version 4.13.3
  * Minimal GTK version = 3.22
  * Avoid crash: do not clean up data to be used (bxo#14609)
  * Add orientation option to arrange icons (bxo#14979)
  * Fix icon size in Open with submenu (bxo#14774)
  * Add support for RandR's primary monitor (bxo#10688)
  * Sync user's wallpaper selection to AccountsService
  * Restore icons of custom actions
  * Port Settings UI to Glade 3
  * Add padding to some context menu icons (bxo#14628)
  * Translation Updates
- Changes from 4.13.2
  * Use the new Thunarx-3 API (Thunar >= 1.7)
  * Use custom CSS for the iconview as a fallback (bxo#13609)
  * Get/set _NET_DESKTOP_MANAGER_S<screen> atom (bxo#13653)
  * Make "another desktop manager is running" messages critical (bxo#13653)
  * Change "Create Launcher..." icon (bxo#14161)
  * Do not popup a single "Applications" menu when right clicking on desktop (bxo#13866)
  * Single-click mode executes desktop items twice (bxo#14021)
  * Fix menu popup issue with desktop icons disabled (bxo#14415)
  * Fix memory leak : Don't try to allocate all the memory (bxo#12805)
  * Fix some autotools warnings and bump dependencies
  * Make a couple of strings translatable (bxo#14374)
  * Translation Updates
- Changes from 4.13.1
  * Fix a memory leak reported in bxo#13555
  * Fix garcon-2 dependancy check (continue to use garcon-1)
  * Translation Updates
- Changes from 4.13.0
  * Port to GTK version = 3.22
  * Fix icon size in Open with submenu (bxo#147743)
  * The iconview has a CSS name of "XfdesktopIconView" and
    adds the GTK_STYLE_CLASS_VIEW to it's base. It then adds
    GTK_STYLE_CLASS_LABEL when rendering the icon text with
    the states: selected, active, or normal. Additionally it
    uses the GTK_STYLE_CLASS_RUBBERBAND when for the rubberband
    theming.
  * Port to GDBus.
  * Don't redraw the icons on focus change events (bxo#12071)
  * Don't try to divide by 0 (bxo#12115)
  * Settings: Fix loading of wallpaper previews (bxo#11892)
  * Settings: Allow directories to be selected (bxo#12832)
  * Fix Open dialog's title (bxo#12560)
  * Prevent a crash in the backdrop loader (bxo#12339)
  * Use gdk's get static image for animation files
  * Add translation string for Trash desktop icon
  * Retain icon relative position when moving a group
- Clean up spec file and dropped obsolete macros
- Added conditional %%bcond_with git for easier maintanance when using
  git master branch
- Dropped obsolete 0001-Use-the-new-Thunarx-3-API.patch
- Fixed patch xfdesktop-default-background-image.patch
- Dropped obsolete wallpaper-scaling.patch (fixed upstream)
* Wed Jun  5 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- update to version 4.12.5
  * Desktop icons order resets (bxo#11266)
  * Match Thunar DnD behavior (bxo#14919)
  * Fix icon size in Settings -> Default Icons
  * Avoid invalid memory access (bxo#15299)
  * Avoid timer leak when docking-undocking monitors (bxo#13887)
  * Use clipboard target "text/uri-list" on copy/cut (bxo#13379)
* Wed May  8 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Added wallpaper-scaling.patch. Fixes boo#1134125
* Sun Jun 17 2018 seife+obs@b1-systems.com
- update thunarx dependency
- add 0001-Use-the-new-Thunarx-3-API.patch for thunarx-3 usage
- use %%license intead of %%doc for COPYING file
- remove empty %%post/%%postun
* Wed Jul 19 2017 seife+obs@b1-systems.com
- update to version 4.12.4
  - Work around a regression in Gtk2 allowing directories to be
    selected in the settings dialog bxo#12832
  - Don't try to divide by 0 bxo#12115
  - Add DBUS_CFLAGS and DBUS_LIBS so that it compiles with newer
    xfconf.
- packaging: package NEWS instead of ChangeLog file, significantly
  reducing package size
* Thu Nov 24 2016 seife+obs@b1-systems.com
- update to version 4.12.3
  - rotate wallpaper images if they contain rotation information
  - Settings: Fix loading of wallpaper previews
  - fix setting of wallpaper if monitor name contains whitespace
  - translation updates
* Sun May 17 2015 gber@opensuse.org
- update to version 4.12.2
  - optimized sorting wallpapers (bxo#11817)
  - don't sort the image list when randomly cycling (bxo#11817)
  - don't load an image list unless we're cycling (bxo#11817)
  - allow dragging desktop launchers to the panel (bxo#2794)
  - load emblem-unreadable if necessary
  - bail out when a negative value was calculated for row/col.
    (bxo#11782)
  - hide empty comment line in icon tooltip
  - fix build error (bxo#11778)
  - ignore shadow blur radius when calculating icon text box
  - prefer "_NETSCAPE_URL" over "text/uri-list" (bxo#9632)
  - drop explicit LibSM check (bxo#11744)
  - preserve order when moving multiple icons (bxo#11195)
  - drop warning when D-Bus timeout error occurs (bxo#11283)
  - add default wallpaper folder to file chooser (bxo#11715)
* Sun Mar 22 2015 gber@opensuse.org
- update to version 4.12.1
  - remove unused variable 'tmp_text'
  - monitor the wallpaper file for changes (bxo#11620)
  - reinitialize background when reloading desktop (bxo#11620)
  - update rc file after completing delete process (bxo#11692)
  - add a xfconf settings to center the text on xfdesktop icons;
    this fixes some issues with RTL languages.
  - do not overwrite rc file while restoring icons (bxo#11266)
  - fix crash when moving 2+ icons to the bottom right corner
  - fix icon placement when using "Arrange Desktop Icons"
    (bxo#11639)
  - center icons vertically in the grid (bxo#11086)
  - set initial value of font size spin button
  - show sub directories in template menu again
  - prevent accidental double clicks in single click mode
    (bxo#10720)
  - disable rename menu entry for special icons
  - add icon emblems in clockwise order
  - handle icons with preset emblems (bxo#7417)
  - enable drag&drop popup menu for local actions
  - use mini icon and allow dimming of non-scaled icons
  - translation updates
* Sat Feb 28 2015 gber@opensuse.org
- update to version 4.12.0
  - new background for 4.12!
  - add a space between icons to fill the entire screen
  - add optional blurring on shadow on text of icons
  - editing menu items with right click optional
    (bxo#11031)
  - clarify right click apps menu presence (bxo#10301)
  - default application not respected with glib >= 2.41
    (bxo#11306)
  - include dir needed for building "out of tree"
  - fix crash in xfdesktop's metadata monitor
  - add 1px to widen the text shadow and improve contrast
  - fix calculation of shadows that are offset in RTL
    text (bxo#5239)
  - adapt thunar's context menu structure (bxo#11542)
  - additional context menu changes
  - consider shadow offsets and blur extents when
    calculating the text box
  - sort pending icons on resize (bxo#11266)
  - allow thunarx menu entries for multiple file selection
  - show 'No templates installed' when no templates
    are found
  - hide file action menu entries when volume + other
    icons are selected
  - don't use cairo_surface_create_similar_image
    (bxo#11566)
  - consider shadow extents/offsets when updating icon
    extents
  - translation updates
- remove obsolete xfdesktop-fix-default-application-lookup.patch
- rebased xfdesktop-default-background-image.patch
* Mon Nov 17 2014 gber@opensuse.org
- add xfdesktop-fix-default-application-lookup.patch in order to
  fix the default application lookup with gio >= 2.41 (bxo#11306)
* Mon Sep 15 2014 gber@opensuse.org
- update to version 4.11.8
  - fix xfdesktop --reload in spanning mode
  - settings: Fix background color loading
  - add an --enable-debug option added to xfdesktop-settings
  - fix icon loading for .desktop files
  - don't show infobar when there's only 1 workspace
  - remove the drag highlight code
  - translation updates
* Mon Aug 11 2014 gber@opensuse.org
- update to version 4.11.7
  - add an option to show hidden files
  - add a --next option to force wallpaper changes
  - add runtime debug support
  - add a move to trash menu option
  - change behaviour to behavior
  - Matias De lellis: Fix display desktop file that include
  extension in icon name
  - Matias De lellis: Fix missing thumbnail on xfdesktop when
  thumbler fails to create it
  - Mauro Giubileo: Fix icon position saving on resolution change
  - translation updates
* Thu May  1 2014 gber@opensuse.org
- update to version 4.11.6
  - miscellaneous bug fixes:
  - g_file_trash_async is too new (bxo#10786)
  - don't chain up style_set (bxo#10788)
  - fix for moving icons into folders on the desktop (bxo#10785)
  - fix issues with file move events (bxo#10796)
  - use GTK_STOCK_EXECUTE for Execute menu entry (bxo#10800)
  - change default image style to zoomed
  - fix for monitors not getting updated
  - hook up the signal handlers in xfdesktop-settings
  - miscellaneous bug fixes:
  - disconnect the directory signal handler when changing folders
  - correct an additional default icon size setting
  - fix for images not appearing in settings app (bxo#10685)
  - reset the icon_view style on style change (bxo#10605)
  - filter out changed events for special icons (bxo#10755)
  - use GIO directly for delete/trash operations (bxo#10778)
  - G_CONST_RETURN has been deprecated
  - versioned help:
  - point to the docs.xfce.org page for xfdesktop 4.11
    (bxo#10736)
  - build errors with some compiler flags:
  - dbus-glib is now required. Since xfconf requires it and
    xfconf is already required for xfdesktop, this shouldn't
    change dependancies much for xfdesktop. This bug was reported
    and fixed by Samuli Suominen (bxo#10745)
  - another build failure when disabling the menu and requiring
    exo was also resolved
  - icon changes in the settings app:
  - symbolic icons have issues with some gtk2 themes where they
    don't get colored properly. Additionally some themes don't
    have network-fs or gnome-dev-network so it has been changed
    gtk-network
  - right click edits launchers:
  - when performing a right click, or shift + left click, on an
    item in the applications sub-menu of the desktop menu it will
    now pop up the dialog to edit the launcher. Same as
    xfce4-appfinder
  - better migration from previous versions:
  - Xfdesktop now does a better job of migrating any user
    settings from 4.10 and before to the new xfconf properties
  - fix an settings issue when plug names aren't available
  - clean up some user strings:
  - some tooltips end with a period, some do not. This has been
    unified
  - "You are using more than one display, move this dialog to the
    display you want to edit the settings for." This takes a lot
    of space and brings along a bit of redundancy. Changed to
    "Move this dialog to the display you want to edit the
    settings for."
  - "Other items" on the third tab, below removable devices:
    "devices" replaces "items"
  - remember the window size of the settings dialog
  - fix segfault on session start
  - miscellaneous bug fixes:
  - iconview theme/gtkrc color/style issues resolved
  - issues with folder cover art not loading have been fixed
  - make xfdesktop-settings pluggable again (bxo#10714)
  - update the wallpapers after user sets folder in the settings
    app
  - minimize grid resizes, it now won't recalculate icon
    positions if the grid size didn't actually change
  - memory leaks fixed
  - warnings that happened during runtime have been fixed
  - fix a crash when removing displays
  - show add/remove workspace option is on by default
  - multi-monitor fixes:
  - release pixmap on screen changes
  - always redraw backdrop on display change
    both patches were added so that transitions from one monitor
    to another cause the backdrop to properly display
  - update default icon size, spacing, and text proportion
  - scale up small image previews in xfdesktop-settings (bxo#10690)
  - fix strict aliasing issue
  - check for thumbnails in the new location
  - fix issues with icon resizing
  - refresh desktop on style changes
  - fix potential bugs found with static code analysis tools
  - fix keyboard cursor movement in the icon view
  - fix some runtime warnings
  - ensure a quit signal causes xfdesktop to shutdown
  - fix icon labels in RTL languages (bxo#10604)
  - use get_folder_actions for clicks on the desktop itself
  - only use thunarx_menu_provider_get_file_actions (bxo#10492)
  - xfdesktop-settings:
  - add xfconf property to toggle the display of the add/remove
    workspace menu items in the middle click menu (bxo#4278,
    bxo#7337)
  - add an info bar to xfdesktop-settings so it is clearer on how
    to customize additional workspaces and monitors (bxo#10460)
  - keyboard navigation has been improved in xfdesktop-settings
  - port Xfdesktop to the GApplication API:
  - Xfdesktop now uses the GApplication API to handle process
    uniqueness, message passing, and life cycle management
  - improve how Xfdesktop transitions from the login manager to
    the initial wallpaper display; all bugs were reported and
    resolved by Alistair Buxton:
  - don't set the root pixmap until it's been drawn
  - don't show the window until the background is ready
  - don't set ESETROOT
  - scale down over-sized icons in menus so they have a uniform
    appearance (bxo#10545, bxo#10461)
  - move max-template-files xfconf property
  - remove old GLIB/GTK macro checks
  - update man page
  - wait for the window manager to prevent issues where the
    wallpaper and icons won't show up on additional screens
    during startup (bxo#7769)
  - fix icon renames causing duplicate icons
  - fix icons for .desktop files with absolute paths
  - don't show hidden or backup files on the desktop (bxo#9001)
  - fix a couple warning messages that happen when xfdesktop is
    shutdown while it's still starting up
  - improve how backdrops are chosen
  - wrong g_return_if_fail macro used
  - fix icon moves and deletions
  - don't cache the pixbufs in single workspace mode
  - clear all pixels from drag highlight box (bxo#10450)
  - speed up template sub-menu loading code (bxo#7834)
  - always move files from the trash (bxo#3983)
  - fix template sub-menu loading code (bxo#10138)
  - fix menu popups via the command line
  - use the Path key of desktop files if a path is not set
    (bxo#8741)
  - correctly display settings defaults
  - fix some memory leaks
  - include the chronological option in the combobox
  - allow the font size to go to 0
  - tooltip options in xfdesktop-settings
  - add a chronological backdrop cycle option
  - additonal backdrop cycle options
  - more removable device icon types (bxo#4056)
  - add icons in an idle callback
  - right click issues persist (bxo#9323)
  - migrate backdrop settings from previous versions (bxo#10380)
  - set warnings as fatal
  - update manpage (bxo#7576)
  - allow renaming of multiple icons
  - no need to remove the thumbnail if we're removing the icon
  - fix for renames removing icons
  - use GdkPixbufLoader for backdrops
  - change how icon positions are saved (bxo#9192)
  - avoid calling g_object_ref on NULL
  - fix for trash always showing empty on system startup (bxo#9006)
  - fix warnings and obsolete macros
  - fix a critical error message on exit
  - fix compiling with --disable-desktop-icons
  - custom folder icons (bxo#8326)
  - hold the cursor grab when presenting the menu (bxo#9323)
  - use async functions when working with the dbus filemanager
    (bxo#9105)
  - lower update delay of icon size spinbutton (bxo#9882)
  - unselect the desktop icon after activating it. (bxo#8640)
  - icon stays in place when renamed (bxo#1678)
  - better icon pixbuf caching
  - make inactive workspace headers insensitive in color
  - clean up middle-click menu appearance
  - fill in the icon area better
  - use GIcons and add support for emblems on icons
  - align icon labels and allow them to be multi-line (bxo#8646)
  - fix a crash when changing icon types
  - fix for CTRL + drag selections (bxo#10275)
  - more consistent icon placement (bxo#8814)
  - remove old migration code
  - fix HTTP URL performance issue / wrong action proposed
  - decide on move/copy action before items have been dropped
  - clip overlapping backdrops (bxo#9052)
  - fix memory leaks
  - apply wallpaper to all workspaces option
  - port fix for bxo#9892 from the xfce-4.10 branch
  - thumbnail service support to xfdesktop-settings (bxo#6536)
  - improve the eject/unmount notifications (bxo#9845)
  - Xfdesktop supports per-workspace wallpapers (bxo#369)
  - add a tabs width of padding for tooltip text (bxo#9162)
  - add a signal handler for removable devices to update the icon
    When the theme is changed (bxo#8977)
  - add an unmount option and notifications when a device is
    removed (bxo#7610)
  - made changes so that DISABLE_DEPRECATED and GSEAL flags can be
    enabled
  - autotools updates
  - translation updates
- drop obsolete xfdesktop-automake-1.13.patch
* Wed Mar 13 2013 pgajdos@suse.cz
- builds with automake 1.13
  * automake-1.13.patch
* Sun Mar 10 2013 gber@opensuse.org
- update to 4.10.2
  - fix hang when no backdrop image is selected
  - fix tiling for some images.
* Thu Mar  7 2013 gber@opensuse.org
- update to version 4.10.1
  - add a tabs width of padding for tooltip text
  - fix theming of removable devices' icons
  - SVG images are no longer pixilated when scaled up
  - improve menu icon loading
  - fix background cycling
  - fix a crash when minimized window icons are resized
  - fix use-after-free in xfdesktop_regular_file_icon_peek_tooltip
  - translation updates
- dropped obsolete xfdesktop-fix-backdrop-timer.patch and
  xfdesktop-4.10.0-fix-use-after-free.patch
* Tue Jan 29 2013 gber@opensuse.org
- fix the default path for background images in the settings dialog
  (bnc#800970)
* Thu Dec 20 2012 gber@opensuse.org
- added xfdesktop-fix-backdrop-timer.patch in order to fix the
  backdrop timer not being rescheduled (bnc#793723, bxo#8962)
* Wed Jun 27 2012 seife+obs@b1-systems.com
- fix use-after-free in desktop icon tooltip code (bnc#768985)
* Wed May  9 2012 gber@opensuse.org
- add versioned dependencies
* Tue May  1 2012 gber@opensuse.org
- rename %%{_datadir}/wallpapers/xfce/default.jpg to
  %%{_datadir}/wallpapers/xfce/default.wallpaper, the default
  wallpaper formats may differ and xfdesktop doesn't care about
  the filetype extension
* Sun Apr 29 2012 gber@opensuse.org
- update to version 4.10.0
  - use the correct default value for the 'show thumbnails'
    checkbox
  - remove deprecated glib/gio functions
  - translation updates
- added dependency on exo-tools since it uses exo-desktop-item-edit
* Fri Apr 27 2012 gber@opensuse.org
- add dependency on libgarcon-data which provides menu data
* Sat Apr 14 2012 gber@opensuse.org
- update to version 4.9.3
  - fix dependency versions
  - hide unneeded message on startup
  - apply single click option on startup
  - disable the resize grip from the root window
  - add new background and remove old ones
  - make string translatable
  - fix a mnemonic conflict
  - simplify the menu reloading
  - translation updates
- added xfdesktop-default-backdrop-image.patch which sets the
  default backdrop image to a symlink that is delivered by branding
  packages
- added xfdesktop-backgrounds-path.patch in order to deliver
  background images under DATADIR/wallpapers which is already used
  by openSUSE
* Sun Apr  8 2012 gber@opensuse.org
- update to version 4.9.2
  - enable pseudo-transparent backgrounds again
  - fix menu without desktop icons
  - use the preferred file manager when opening folders
  - keep the image width to something sensible for
    xfdesktop-settings
  - change xfdesktop's menu icon to "applications-other"
  - prevent multiple instances of xfdesktop from running
  - comments in .desktop files are displayed in the tooltip
  - get correct workspace size with multimon display
  - fix xinerama_stretch not refreshing on all monitors
  - added the root menu popup when there are no icons shown on the
    desktop
  - fix a segfault when tumbler isn't available
  - single click option to open items on desktop
  - arrange icons on the desktop
  - always use gdk_screen_get_monitor_geometry
  - stretch background across all monitors setting
  - unmounted volumes are semi-transparent
  - fix for moving files instead of copy when src isn't writable
  - modified xfdesktop_icon_view_drag_drop to allow all selected
    files to drag and drop
  - backdrop image cycling on a timer
  - change to POINTER_MOTION_HINT_MASK & use
    gdk_event_request_motions
  - icon positions are saved/restored per resolution
  - fix for shift + drag selections
  - display correct trash icon on menu & desktop
  - adds the code required to perform a paste on the on the
    desktop
  - thumbnail desktop icon previews using tumblerd
  - added a check for GDK_GRAB_INVALID_TIME in
    xfdesktop_popup_grab_available to mitigate slow menu popups on
    a right mouse click
  - right-click Drag and Drop
  - show dialog in settings category
  - remove docs and link to wiki
  - drop AC_PROG_LIBTOOL for LT_PREREQ and LT_INIT
  - fix moving files to the desktop with shift & drag
  - fix some compiler warnings
  - fix window actions on minimised windows' icons
  - fix creation of empty file from template menu
  - fix potential crash in xfdesktop-settings
  - retrieve the translated desktop file name
  - fix crash on focus in when items are selected
  - properly invalidate tooltips on file changes
  - fix crash when cancelling a file download
  - implement open and empty actions for the trash
  - implement monitoring for special file icons like the trash
  - scroll to the selected background in the settings
  - support absolute icon paths in desktop files
  - handle volume changes in a timeout
  - make sure the background is reloaded on compositing changes
  - use Name field as display name of desktop files
* Sat Apr  7 2012 gber@opensuse.org
- added xfdesktop-fix-slow-popup-menu.patch which adds a check for
  GDK_GRAB_INVALID_TIME in xfdesktop_popup_grab_available to
  mitigate slow menu popups on a right mouse click (bnc#669768,
  bxo#7172)
* Thu Mar 29 2012 gber@opensuse.org
- split off -lang subpackage
- specfile cleanup
* Fri Oct 21 2011 gber@opensuse.org
- install HTML documentation under /usr/share/xfce4/xfdesktop/html
* Mon Sep 19 2011 gber@opensuse.org
- update to version 4.8.3
  - fix moving files to the desktop via shift & drag
  - translation updates
* Mon Jun 13 2011 gber@opensuse.org
- update to version 4.8.2
  - retrieve the translated desktop file name
  - bugfixes
  - translation updates
* Fri Feb 18 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Thu Feb  3 2011 gber@opensuse.org
- update to version 4.8.1
  - bugfixes
  - translation updates
- dropped obsolete xfdesktop-4.8.0-fix-volume-change-handling.patch
  and xfdesktop-4.8.0-show-name-of-desktop-files.patch
* Wed Jan 26 2011 gber@opensuse.org
- add xfdesktop-4.8.0-fix-volume-change-handling.patch from
  upstream git in order to work around an issue with GIO or GVfs
  which causes mounting/unmounting on a volume-changed signal to
  fail
* Sat Jan 22 2011 gber@opensuse.org
- added xfdesktop-4.8.0-show-name-of-desktop-files.patch so that
  the Name field of desktop files is shown rather than the filename
* Mon Jan 17 2011 gber@opensuse.org
- update to version 4.8.0
  * optimized backdrops
  * removed flower backdrop
* Wed Jan  5 2011 gber@opensuse.org
- added -branding-upstream subpackage
- obsoleted xfce4-desktop branding which is now provided by
  xfdesktop-branding
* Tue Dec 28 2010 gber@opensuse.org
- show compiler output
- do not install documentation in /usr/share/doc
- improved description
* Sun Dec  5 2010 prusnak@opensuse.org
- updated to 4.7.4
  * Add checks for an API change in libnotify 0.7.0 (bug #6915).
  * Avoid GTK+ 2.18 and GIO 2.20 function calls (or at least guard them
    so that xfdesktop still builds with older versions).
  * Let garcon choose the default applications menu file using
    XDG_MENU_PREFIX. Drop the UserMenu kiosk option as the panel
    sort of allows to bypass it anyway.
- updated to 4.7.3
  * Fix a crash caused by accessing the wrong variable when adding
    items to the right-click menu.
  * Select the correct icon style in the desktop settings on first
    start (bug #6798).
  * Depend on libwnck >= 2.22 so we no longer have to implement hacks
    for the two different "active-workspace-changed" signal variants
    in libwnck (bug #6638).
  * Add menu item monitoring.
  * Fix critical when session manager is not running (bug #6822).
  * Remove checks for older GLib/GTK+ versions that are no longer needed.
  * Allow workspace names that start with a number (bug #6318).
  * Delay notification initialization until we show one.
  * Set the correct session priority.
  * Do not call gtk_widget_show() on menus (bug #6198).
  * Translation updates: gl, ca, de, it, kk, fi, sk, pt, uk, el,
    zh_TW, da, id, eu, hu, lt.
* Fri Dec  3 2010 gber@opensuse.org
- do not require xfce-utils
* Wed Dec  1 2010 prusnak@opensuse.org
- use pkgconfig symbol in BuildRequires
* Fri Nov 26 2010 andrea@opensuse.org
- renamed package to xfdesktop to follow upstream
- updated to version 4.7.2
* Sun Jul 18 2010 bernhard@bwalle.de
- updated to 4.6.2
  == xfdesktop
  o Build fixes for GIT.
  o Rebuild doc directory.
  o Add libexo to CFLAGS and LIBS for panel plugin.
  o Fix detection of rename/delete ability.
  o Fix compilation when libexo isn't present.
  o Update icon text labels when system font size changes (bug #2862).
  o Set mnemonic widget properly for icon type/size labels (bug #5555).
  o Always show 'Eject' in volume context menus, regardless of whether
    or not it's mounted (bug #5343).
  o Never show 'Unmount' in volume context menus.
  o Use GtkBindingSet for keyboard handling on desktop.
  o Only register menu with panel if popup succeeded (bug #5792).
  o Fix inability to delete broken symlinks on the desktop (bug 5387).
  o Don't misuse the g_return_(val_)?if_fail() macros as much (bug #5791).
  o Translation updates (el, es, gl, it, pl, pt, ru, tr, ro, lv, ca,
    ur, ur_PK, hu, ast, da, sk, nn, nl, si, am, kk, ja, ug, fr).
  == xfce-utils
  o Build fixes for GIT.
  o Fix make distcheck.
  o Translation updates (es, gl, pl, ro, lv, ur, ur_PK, hu, ast, ru,
    it, ta, nl, kk, nb_IN, sk, ug).
* Tue Jun 15 2010 bernhard@bwalle.de
- Fix xfce-utils-cpp.patch to patch also the '*.in' files.
* Thu Mar 18 2010 prusnak@suse.cz
- build branding subpackage as noarch
* Tue Jul 21 2009 dominique-obs@leuenberger.net
- Use libexecdir instead of libdir where appropriate
* Tue Apr 21 2009 prusnak@suse.cz
- updated to 4.6.1
  == xfdesktop
  * Fix desktop menu failing to load on FreeBSD (bug 3370).
  * Ensure root window properties get deleted when xfdesktop
    quits (bug 5154).
  * Reload the backdrop and icon view when 'xfdesktop --reload'
    is run (bug 5156).
  * Make default button in 'delete multiple' dialog consistent with
    default in 'delete single' dialog (bug 5140).
  * Reload the desktop when the first image is added to an image
    list (bug 5001).
  * Auto-select new images as they are added to the settings dialog's
    image list (bug 5014).
  == xfce-utils
  - Reset icon theme name if the migrated icon theme name (possibly 'Rodent')
  doesn't exist anymore.
  - Remove a bash-ishm ('source') from xinitrc.
* Fri Feb 27 2009 prusnak@suse.cz
- updated to 4.6.0 (Xfce 4.6.0 release)
* Tue Nov 18 2008 pnemec@suse.cz
- call update_desktop_file macro on desktop files [bnc#445722]
* Wed Oct 29 2008 bwalle@suse.de
- update to xfdesktop 4.4.3
  o Make menu panel plugin honor CustomizeDesktopMenu kiosk setting
  o Fix incorrect initial desktop font size when setting custom
    font size if a custom font was never set before
- update to xfce-utils 4.4.3
  o Fix missing translated chars
- drop xfdesktop-relocation-and-memleak.patch: mainline
* Mon Oct 13 2008 bwalle@suse.de
- Use the right patchlevel.
* Wed Oct  8 2008 bwalle@suse.de
- Fix compiler warning (bnc#433391).
* Mon Oct  6 2008 sbrabec@suse.cz
- Conflict with other branding providers (FATE#304881).
* Fri Aug  1 2008 prusnak@suse.cz
- fixed relocation and memleak (relocation-and-memleak.patch)
- do not show YaST modules in Xfce menu - workaround for [bnc#393955]
  (no-yast-desktop-files.patch)
* Mon Jul 28 2008 prusnak@suse.cz
- moved /etc/xdg/xfce4/desktop/menu.xml.* to branding subpackage
* Tue Apr 29 2008 prusnak@suse.cz
- moved backdrops to %%{_datadir}/wallpapers
- split upstream backdrops to xfce4-desktop-branding-upstream
* Sun Mar 16 2008 crrodriguez@suse.de
- fix file-not-in-lang rpmlint warnings
* Wed Dec 12 2007 prusnak@suse.cz
- correct eject function (xfdesktop-eject.patch)
* Mon Dec  3 2007 bwalle@suse.de
- update to xfdesktop 4.4.2
  o Fixed the Italian xfdesktop menu causing a crash.
  o Fix missing xfce_rc_close() causing memleak and too many open
    file descriptors
  o Always use button 0 in gtk_menu_popup() as GTK+ 2.11+ expects
    the same button to be pressed or it doesn't activate the entry
  o Fix menu sometimes not popping up when using the keyboard
    shortcut, again. Timeout waiting for grab is now 0.25s
  o Fix desktop settings only getting applied to the first screen in
    non-Xinerama dualhead setups
  o Fix spurious drag when double-clicking a volume icon that fails
    to mount
  o Clean out stale entries in icon position file
  o Some minor memory leak fixes (some still remain, likely).
  o Fix --disable-menu-editor configure option.
- update to xfce-utils 4.4.2
  o Put back a default DPI value for Xorg
  o Use gnome-screensaver if xscreensaver is not available
  o Fix typo on XDG_DATA_DIRS path definition
  o Updated credits in the about dialog.
  o Updated and new translations
* Mon Aug 13 2007 bwalle@suse.de
- fixed problem that menu doesn't start applications from desktop
  with gtk+-2.11.x (Xfce bxo#3359)
* Sat Jun 23 2007 bwalle@suse.de
- replaced group 'System/GUI/Other' by 'System/GUI/Xfce'
* Fri Jun  8 2007 bwalle@suse.de
- remove /usr/share/apps/switchdesk/Xclients.xfce4
* Tue May 22 2007 prusnak@suse.cz
- sync with BuildService
* Tue Apr 10 2007 bwalle@suse.de
- update to 4.4.1
  o Fix entries in the menu.xml files that should not have been
    translated.
  o Remove use of __FUNCTION__ as it breaks sun's compiler.
  o Blurry rendering of unscaled backgrounds.
  o Unescape %% characters in the uri.
  o Many translation updates.
* Mon Mar  5 2007 pnemec@suse.cz
- remove /usr/share/xsessions from file section [#229172]
* Thu Feb  1 2007 prusnak@suse.cz
- removed duplicate copyright header from spec file [#238045]
- removed sessions for display managers in /etc
  (SUSE uses only /usr/share/xsessions)
* Sun Jan 21 2007 bwalle@suse.de
- upgraded to 4.4.0
* Mon Mar 27 2006 pnemec@suse.cz
- added patch to autogenerate menu, temporary for 4.2.3 (#159376)
* Tue Feb 14 2006 pnemec@suse.cz
- change Mozilla to MozillaFirefox in panel
* Wed Feb  8 2006 pnemec@suse.cz
- added xfce4-session and xfwm to requires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 pnemec@suse.cz
- fixed mistyped spec file
* Mon Jan 16 2006 pnemec@suse.cz
- update to 4.2.3
* Tue Nov 15 2005 pnemec@suse.cz
- added xfce4-panel-devel to need for build
* Thu Sep  8 2005 cthiel@suse.de
- unset SESSION_MANAGER before starting $xfcesm (#115360)
* Mon Aug  1 2005 cthiel@suse.de
- fixed Requires
* Wed May 18 2005 cthiel@suse.de
- update to 4.2.2
* Thu May  5 2005 cthiel@suse.de
- really activate default background patch
* Mon Apr 11 2005 cthiel@suse.de
- update to 4.2.1
- changed default background
* Thu Nov  4 2004 mmj@suse.de
- locale rename: no -> nb
* Mon May 17 2004 ltinkl@suse.cz
- initial version
